# Mortality Prediction

This folder contains tasks for predicting mortality in patients in a variety of clinical contexts. Mortality
is a common prediciton target because

1. The "death" label is unambiguous, clearly important, and (often) easy to collect.
2. Mortality is a common outcome in clinical research, and many studies have collected data that can be used
   to predict mortality.
3. Mortality prediction within specific time-frames can be used as a proxy for the need for greater clinical
   attention on select patients, and mortality has accordingly been used as a training proxy for the
   development of clinical risk scores in various settings. We do not advocate this use of mortality in all
   contexts, but it is a common use-case for mortality prediction tasks.

We break down mortality a variety of categories, all of which are contained in the sub-folders of this task
collection, and described therein.

Missing:

1. Mortality for patients with specific diseases:
   \- \[ \] Sepsis:
   - https://translational-medicine.biomedcentral.com/articles/10.1186/s12967-020-02620-5

Some common references for the prediction of mortality in various settings include: TODO
